
// Vamos importar o modulos para uso!
// express: Um framework web para Node.js que simplifica a criação de servidores HTTP.
// http: Módulo nativo do Node.js para criar servidores HTTP.
// socket.io: Biblioteca para comunicação em tempo real através de websockets.
const express = require('express');
const http = require('http');
const socketIo = require('socket.io');


//app: Aqui, criamos uma instância do aplicativo Express.
//server: Criamos um servidor HTTP usando a instância do Express. Isso nos permite usar o Express para roteamento e middleware, enquanto ainda permite que o socket.io "escute" no mesmo servidor.
//io: Esta é a instância do servidor Socket.io, que vai escutar as conexões websocket no nosso servidor HTTP.
const app = express();
const server = http.createServer(app);
const io = socketIo(server);

// Esta é uma rota do Express para o endpoint / (raiz/dominio). 
//Quando um usuário acessa a raiz do nosso servidor (http://seudominio.com.br/), o Express envia o arquivo index.html que está no diretório atual (__dirname é uma variável global em Node.js que aponta para o diretório do arquivo em execução).
app.get('/', (req, res) => {
    res.sendFile(__dirname + '/index.html');
});

// io.on('connection', (socket) => {...}: Este código define um ouvinte para o evento connection. Esse evento é disparado sempre que um novo cliente se conecta ao servidor via socket.io. O parâmetro socket representa a conexão individual do cliente.
// socket.on('chat message', (msg) => {...}: Aqui, definimos um ouvinte para o evento personalizado chat message. Este evento é emitido pelo cliente quando uma nova mensagem é enviada. Quando recebido, emitimos o mesmo evento para todos os clientes conectados com io.emit('chat message', msg). Isso significa que, quando um cliente envia uma mensagem, todos os outros clientes recebem essa mensagem.
// socket.on('disconnect', () => {...}: Este é um ouvinte para o evento disconnect, que é disparado quando o cliente se desconecta do servidor.
io.on('connection', (socket) => {
    console.log('Usuário conectado');

    socket.on('chat message', (msg) => {
        io.emit('chat message', msg);
    });

    socket.on('disconnect', () => {
        console.log('Usuário desconectado');
    });
});

// Aqui será a porta que o PM2 irá colocar automaticamente! 
// Deixe assim para funcionar na Integrator Host
const PORT = process.env.PORT 
//const PORT = 3000;

server.listen(PORT, () => {
    console.log(`Servidor rodando na porta ${PORT}`);
});
